@@ -15,6 +15,7 @@ from preggy import utils
 
 _registered_assertions = utils.AssertionsMap()
 
+
 def assertion(func):
     '''Function decorator.  Provides lower-level control for custom
     assertions than `@preggy.create_assertions`.
@@ -29,12 +30,29 @@ def assertion(func):
 
     Whenever possible, you should declare both the normal assertion as well
     as a `not_` counterpart, so they can be used like this:
-
-        expect(5).to_be_a_positive_integer()
-        expect(-3).Not.to_be_a_positive_integer()
+    
+    ... # doctest: +ELLIPSIS, +NORMALIZE_WHITESPACE
+    >>>
+    >>> import preggy
+    >>> from preggy.core import Expect as expect
+    >>> 
+    >>> @preggy.assertion
+    ... def to_be_a_positive_integer(topic):
+    ...     if not topic > 0:
+    ...          raise AssertionError("Expected topic('{topic}') to be a positive integer".format(topic=topic))
+    ...
+    >>> @preggy.assertion
+    ... def not_to_be_a_positive_integer(topic):
+    ...     if not topic < 0:
+    ...          raise AssertionError("Expected topic('{topic}') not to be a positive integer".format(topic=topic))
+    ...
+    >>> expect(5).to_be_a_positive_integer()
+    >>> expect(-3).Not.to_be_a_positive_integer()
 
     '''
-
+    if not hasattr(func, 'humanized'):
+        setattr(func, 'humanized', utils.humanized_name(func.__name__))
+        
     @functools.wraps(func)
     def wrapper(*args, **kw):
         return func(*args, **kw)
@@ -55,75 +73,81 @@ def create_assertions(func):
         def to_be_greater_than(topic, expected):
             return topic > expected
 
-    Now, the following expectation…
-
-        expect(2).to_be_greater_than(3)
-
-    …will report:
-
-        Expected topic(2) to be greater than 3.
-
-    It will also create the corresponding `not_` assertion:
-
-        expect(4).not_to_be_greater_than(3);
-
-    …will report:
-
-        Expected topic(4) not to be greater than 3.
-
+    This creates both the assertion AND its `not_*` counterpart.  
+    
+    ... # doctest: +ELLIPSIS, +NORMALIZE_WHITESPACE
+    >>> from preggy.core import (assertion, create_assertions, Expect as expect)  
+    >>> from preggy.assertions import *
+    
+    >>> expect(2).to_be_greater_than(3)
+    Traceback (most recent call last):
+        ...
+    AssertionError: Expected topic(2) to be greater than 3
+    
+    >>> expect(4).not_to_be_greater_than(3)
+    Traceback (most recent call last):
+        ...
+    AssertionError: Expected topic(4) not to be greater than 3
+    
     '''
-
+    # set custom func attribute "humanized"
+    setattr(func, 'humanized', utils.humanized_name(func.__name__))
 
     # modified functools.update_wrapper
-    def _update_wrapper(wrapper, wrapped):
+    def _update_wrapper(wrapper, wrapped, not_assertion=True):
         '''A modified version of functools.update_wrapper. Auto-modifies the
         wrapper's __name__ and __doc__ to create a not_assertion.
         '''
-        # the usual
+        # begin as usual
         wrapper = functools.update_wrapper(wrapper, wrapped)
+        
+        # compute overrides for not_* assertions values
+        if not_assertion:
+            new_name = 'not_{0.__name__}'.format(wrapped)
+            new_doc = ''#.format(wrapped)
 
-        # compute our overrided values
-        new_name = 'not_{0.__name__}'.format(wrapped)
-        new_doc = ''#.format(wrapped)
-
-        # set our overrides
-        setattr(wrapper, '__name__', new_name)
-        setattr(wrapper, '__doc__', new_doc)
+            # set our overrides
+            setattr(wrapper, '__name__', new_name)
+            setattr(wrapper, '__doc__', new_doc)
+            # update to reflect new __name__
+            setattr(wrapper, 'humanized', utils.humanized_name(wrapper.__name__))
 
         # Return the wrapper so this can be used as a decorator via partial()
         return wrapper
-
-    # Generate first assertion with existing decorator
+    
+    
+    # First assertion
     @assertion
     @functools.wraps(func)
     def test_assertion(*args):
-        raw_msg = utils.format_assertion_msg(utils.humanized_name(func), *args)
+        raw_msg = utils.format_assertion_msg(func.humanized, *args)
         err_msg = raw_msg.format(*args)
         if not func(*args):
             raise AssertionError(err_msg)
-
-    # Second assertion: begin
+    
+    # Second assertion: prepare
     def test_not_assertion(*args):
-        raw_msg = utils.format_assertion_msg(utils.humanized_name(func), *args)
-        raw_msg = 'not {0}'.format(raw_msg)
+        raw_msg = utils.format_assertion_msg('not {0!s}'.format(func.humanized), *args)
         err_msg = raw_msg.format(*args)
         if func(*args):
             raise AssertionError(err_msg)
 
-    # Second assertion: update
+    # Second assertion: update and register
     test_not_assertion = _update_wrapper(test_not_assertion, func)
-
-    # Second assertion: register
-    assertion(test_not_assertion)
+    test_not_assertion = assertion(test_not_assertion)
 
 
 class Expect(object):
     '''This atypical class provides a key part of the preggy testing syntax.
-
+    
     For example:
-
-        expect(True).to_be_true()
-
+    
+        >>> from preggy.core import (assertion, create_assertions, Expect as expect)
+        >>> from preggy.assertions import *
+        >>>
+        >>> expect(True).to_be_true()
+        >>> expect(False).to_be_false()
+        
     '''
 
     def __init__(self, topic):
@@ -131,25 +155,16 @@ class Expect(object):
         self.not_assert = False
 
     def __getattr__(self, name):
-        # common cases
-        if name == 'topic':
-            return super(Expect, self).__getattr__(name)
         if name == 'Not':
             self.not_assert = not self.not_assert
             return self
 
         # determine whether assertion is of "not" form
         method_name = 'not_{name}'.format(name=name) if self.not_assert else name
-
+        
         # if program gets this far, then it’s time to perform the assertion. (...FINALLY! ;D)
-        def assert_topic(*args, **kw):
-            '''Allows chained calls to `Assertion`s.  For example, in:
-
-                expect(topic).to_be_true()
-
-            This method is what allows `expect(topic)` to call `.to_be_true()`.
-
-            '''
+        def _assert_topic(*args, **kw):
+            # Allows chained calls to assertions, such as `expect(topic).to_be_true()`.
             return _registered_assertions[method_name](self.topic, *args, **kw)
-
-        return assert_topic
+        
+        return _assert_topic
